@@ -26,7 +26,7 @@ for key in modules:
         if not os.path.exists(MAIN_PATH + "/config"):
             os.makedirs(MAIN_PATH + "/config")
 
-        if not os.path.exists(MAIN_PATH + "/config/config.json"):#
+        if not os.path.exists(MAIN_PATH + "/config/config.json"):
             with open(MAIN_PATH + "/config/config.json", 'w') as config:
                 config.writelines(str(default_config))
 
